@@ -67,7 +67,7 @@ glkerns.formula <- function(formula, data, subset, na.action, ...)
 glkerns.default <- function(x, y=NULL, deriv = 0,
 			    n.out = 300, x.out = NULL, x.inOut = TRUE,
 			    korder = deriv + 2, hetero = FALSE, is.rand = TRUE,
-			    inputb = is.numeric(bandwidth) && bandwidth > 0,
+			    inputb = is.numeric(bandwidth) && all(bandwidth > 0),
 			    m1 = 400, xl = NULL, xu = NULL, s = NULL, sig = NULL,
 			    bandwidth = NULL, trace.lev = 0, ...)
 {
